Documentation — CMIS Library v0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4 documentation »

# Documentation

This documentation was generated with Sphinx. To install Sphinx on Mac OS X using Macports:

MAC OS X:

    sudo port install py26-sphinx

Once you’ve got Sphinx installed, if you need to regenerate the documentation:

    cd /path/to/cmislib/src/doc/src
    Run either:
        sphinx-build -b html -d ../build/.doctrees . ../build
        make html

The generated HTML will be placed in doc/build:

    firefox file:///path/to/cmislib/src/doc/build/index.html

### Navigation

- index
- modules |
- next |
- previous |
- CMIS Library v0.4 documentation »